@@ -20,8 +20,9 @@ class LixingrenIndexData:
         * indicator(q5v-50%分位点 q8v-80%分位点 q2v-20%分位点)
     """
 
-    def __init__(self, lxr_token:str, code: str, start_date: str = None, end_date: str = None, force_update_db: bool = False):
-        self.__v_init(lxr_token=lxr_token, code=code, start_date=start_date, end_date=end_date)
+    def __init__(self, lxr_token: str, code: str, start_date: str = None, end_date: str = None, force_update_db: bool = False):
+        self.__v_init(lxr_token=lxr_token, code=code,
+                      start_date=start_date, end_date=end_date)
         # 从db中取回现有日期
         item_list = ut.db_get_distinct_from_mongodb(
             mongo_db_name=const.MONGODB_DB_LXR,
@@ -32,14 +33,16 @@ class LixingrenIndexData:
             }
         )
         if (len(item_list) == 0) or force_update_db:  # 需要从API获取至db
-            logger.info('选择强制更新或者mongodb中不存在code：%s数据，需要从lxr全量获取...' % self.code)
+            logger.info('选择强制更新或者mongodb中不存在code：%s数据，需要从lxr全量获取...' %
+                        self.code)
             ut.db_del_dict_from_mongodb(
                 mongo_db_name=const.MONGODB_DB_LXR,
                 col_name=const.MONGODB_COL_LXR_INDEX,
                 query_dict={
                     'stockCode': self.code
                 })
-            self.__dict_data_raw = self.__save_index_data_to_db(self.__retrieve_index_data())  # 重新获取
+            self.__dict_data_raw = self.__save_index_data_to_db(
+                self.__retrieve_index_data())  # 重新获取
         else:  # 存在数据，需要比较当前日期和最新日期，确定是否需要更新以及更新范围
             date_list = item_list
             date_list.sort(reverse=True)
@@ -47,15 +50,19 @@ class LixingrenIndexData:
             existed_period = pd.Period(existed_latest_date, 'M')
             today_period = pd.Period(self.__today_date, 'M')
             if today_period > existed_period:  # 差异超过周期，更新数据！
-                start_date = pd.to_datetime(existed_latest_date) + datetime.timedelta(days=1)
-                logger.info('code：%s数据存在，db中最新日期是%s，增量更新....' % (self.code, existed_latest_date))
-                self.__save_index_data_to_db(self.__retrieve_index_data(start_date=start_date.strftime('%Y-%m-%d')))
+                start_date = pd.to_datetime(
+                    existed_latest_date) + datetime.timedelta(days=1)
+                logger.info('code：%s数据存在，db中最新日期是%s，增量更新....' %
+                            (self.code, existed_latest_date))
+                self.__save_index_data_to_db(self.__retrieve_index_data(
+                    start_date=start_date.strftime('%Y-%m-%d')))
             else:
-                logger.info('code：%s数据存在，db中最新日期是%s，无需更新....' % (self.code, existed_latest_date))
+                logger.info('code：%s数据存在，db中最新日期是%s，无需更新....' %
+                            (self.code, existed_latest_date))
 
         self.__populate_item_raw_to_object()
 
-    def __v_init(self, lxr_token:str, code: str, start_date: str = None, end_date: str = None):
+    def __v_init(self, lxr_token: str, code: str, start_date: str = None, end_date: str = None):
         self.lxr_token = lxr_token
         self.code = code
         self.start_date = start_date
@@ -126,7 +133,8 @@ class LixingrenIndexData:
                 },
             )
         else:
-            self.__dict_data_raw = [x for x in self.__dict_data_raw if (self.start_date <= x['date'] <= self.end_date)]
+            self.__dict_data_raw = [x for x in self.__dict_data_raw if (
+                self.start_date <= x['date'] <= self.end_date)]
 
         for day_item in self.__dict_data_raw:
             self.data_dict[day_item['date']] = day_item
