@@ -20,7 +20,7 @@ from PIL import Image
 
 
 class MorningStar:
-    def __init__(self, web_driver_path: str, assets_path: str, cookie_str:str, temp_path:str = './temp_storage.csv'):
+    def __init__(self, web_driver_path: str, assets_path: str, cookie_str:str, temp_path:str = './tests/temp_storage.csv'):
         self.web_driver_path = web_driver_path
         self.assets_path = assets_path
         self.cookie_str = cookie_str
@@ -185,7 +185,7 @@ class MorningStar:
             cookie['name'] = i['name']
             cookie['value'] = i['value']
             # 4.这里需要先删掉之前那次访问时的同名cookie，不然自己设置的cookie会失效
-            # chrome_driver.delete_cookie(i['name'])
+            chrome_driver.delete_cookie(i['name'])
             # 添加自己的cookie
             # print('cookie', cookie)
             chrome_driver.add_cookie(cookie)
